@@ -27,6 +27,7 @@
 #include <goffice/goffice-config.h>
 #include <goffice/goffice-priv.h>
 #include <goffice/goffice-paths.h>
+#include <goffice/goffice-debug.h>
 #include <goffice/app/go-plugin.h>
 #include <goffice/app/go-plugin-service.h>
 #include <goffice/app/go-plugin-loader.h>
@@ -778,7 +779,7 @@ go_plugin_read (GOPlugin *plugin, gchar const *dir_name, GOErrorInfo **ret_error
 	doc = go_xml_parse_file (file_name);
 	if (doc == NULL || doc->xmlRootNode == NULL || strcmp (doc->xmlRootNode->name, "plugin") != 0) {
 		char *uri = go_filename_to_uri (file_name);
-		if (go_file_access (uri, R_OK) != 0) {
+		if (go_file_access (uri, GO_R_OK) != 0) {
 			*ret_error = go_error_info_new_printf (
 			             _("Can't read plugin info file (\"%s\")."),
 			             file_name);
