@@ -21,9 +21,6 @@
 
 #include <goffice/goffice-config.h>
 #include <goffice/goffice.h>
-#ifdef GOFFICE_WITH_GTK
-#       include <gtk/gtk.h>
-#endif
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
 
@@ -120,6 +117,10 @@ enum {
 
 static GObjectClass *item_parent_class;
 
+static GParamSpecPool *style_property_spec_pool;
+static GQuark quark_property_parser;
+static GQuark quark_style_context;
+
 static gboolean
 goc_item_button_pressed (GocItem *item, int button, double x, double y)
 {
@@ -217,12 +218,8 @@ goc_item_dispose (GObject *object)
 			item->canvas->last_item = NULL;
 		if (item->canvas->grabbed_item == item)
 			item->canvas->grabbed_item = NULL;
-#ifdef GOFFICE_WITH_GTK
-		if (gtk_widget_get_realized (GTK_WIDGET (item->canvas))) {
-			item->cached_bounds = TRUE; /* avoids a call to update_bounds */
-			goc_item_invalidate (item);
-		}
-#endif
+		item->cached_bounds = TRUE; /* avoids a call to update_bounds */
+		goc_item_invalidate (item);
 	}
 
 	if (item->parent != NULL)
@@ -285,6 +282,10 @@ goc_item_class_init (GocItemClass *item_klass)
 	item_klass->key_pressed = goc_item_key_pressed;
 	item_klass->key_released = goc_item_key_released;
 #endif
+
+	style_property_spec_pool = g_param_spec_pool_new (FALSE);
+	quark_property_parser = g_quark_from_static_string ("gtk-rc-property-parser");
+	quark_style_context = g_quark_from_static_string ("GocItem::style-context");
 }
 
 static void
@@ -414,7 +415,7 @@ goc_item_draw (GocItem const *item, cairo_t *cr)
 	GocItemClass *klass = GOC_ITEM_GET_CLASS (item);
 	g_return_if_fail (klass != NULL);
 
-	if (klass->draw)
+	if (klass->draw != NULL)
 		klass->draw (item, cr);
 }
 
@@ -441,8 +442,9 @@ goc_item_draw_region (GocItem const *item, cairo_t *cr,
 	GocItemClass *klass = GOC_ITEM_GET_CLASS (item);
 	g_return_val_if_fail (klass != NULL, FALSE);
 
-	return (klass->draw_region)?
-		klass->draw_region (item, cr, x0, y0, x1, y1): FALSE;
+	return (klass->draw_region != NULL)?
+		klass->draw_region (item, cr, x0, y0, x1, y1):
+		FALSE;
 }
 
 static void
@@ -455,10 +457,9 @@ goc_item_maybe_invalidate (GocItem *item, gboolean ignore_visibility)
 	if (!parent)
 		return;
 
-#ifdef GOFFICE_WITH_GTK
-	if (!gtk_widget_get_realized (GTK_WIDGET (item->canvas)))
+	if (!goc_canvas_get_realized (item->canvas))
 		return;
-#endif
+
 	if (!ignore_visibility && !item->visible)
 		return;
 
@@ -809,7 +810,7 @@ goc_item_set_transform (GocItem *item, cairo_matrix_t *m)
 						|| fabs (m->yx) > matrix_epsilon
 						|| fabs (m->yy - 1.) > matrix_epsilon
 						|| fabs (m->x0) > matrix_epsilon
-						|| fabs (m->x0) > matrix_epsilon;
+						|| fabs (m->y0) > matrix_epsilon;
 	if (item->transformed)
 		item->transform = *m;
 	else
@@ -817,7 +818,7 @@ goc_item_set_transform (GocItem *item, cairo_matrix_t *m)
 }
 
 void
-_goc_item_transform (GocItem const *item, cairo_t *cr)
+_goc_item_transform (GocItem const *item, cairo_t *cr, gboolean scaled)
 {
 	cairo_matrix_t m = item->transform, buf,
 		sc = {item->canvas->pixels_per_unit, 0., 0., item->canvas->pixels_per_unit, 0., 0.};
@@ -826,6 +827,70 @@ _goc_item_transform (GocItem const *item, cairo_t *cr)
 			cairo_matrix_multiply (&buf, &m, &item->transform);
 			m = buf;
 		}
-	cairo_matrix_multiply (&buf, &m, &sc);
-	cairo_set_matrix (cr, &buf);
+	if (scaled) {
+		cairo_matrix_multiply (&buf, &m, &sc);
+		m = buf;
+	}
+	cairo_transform (cr, &m);
 }
+
+#ifdef GOFFICE_WITH_GTK
+
+static void
+cb_parent_changed (const GocItem *item)
+{
+	GtkStyleContext *context = goc_item_get_style_context (item);
+	GtkStyleContext *pcontext;
+	GtkWidgetPath *path;
+
+	if (item->parent) {
+		pcontext = goc_item_get_style_context (GOC_ITEM (item->parent));
+	} else if (item->canvas &&
+		   GOC_ITEM (item->canvas->root) == item) {
+		pcontext = gtk_widget_get_style_context (GTK_WIDGET (item->canvas));
+	} else {
+		pcontext = NULL;
+	}
+	if (pcontext)
+		path = gtk_widget_path_copy (gtk_style_context_get_path (pcontext));
+	else
+		path = gtk_widget_path_new ();
+
+	gtk_widget_path_append_type (path, G_TYPE_FROM_INSTANCE (item));
+	gtk_style_context_set_path (context, path);
+	gtk_widget_path_free (path);
+#ifdef HAVE_GTK_STYLE_CONTEXT_SET_PARENT
+	gtk_style_context_set_parent (context, pcontext);
+#endif
+}
+
+
+/**
+ * goc_item_get_style_context:
+ * @item: #GocItem
+ *
+ * Returns: (transfer none): The style context to use for the item.
+ */
+GtkStyleContext *
+goc_item_get_style_context (const GocItem *item)
+{
+	GtkStyleContext *context;
+	g_return_val_if_fail (GOC_IS_ITEM (item), NULL);
+
+	context = g_object_get_qdata (G_OBJECT (item), quark_style_context);
+	if (!context) {
+		context = gtk_style_context_new ();
+		g_object_set_qdata_full (G_OBJECT (item),
+					 quark_style_context,
+					 context,
+					 g_object_unref);
+
+		g_signal_connect (G_OBJECT (item),
+				  "notify::parent", G_CALLBACK (cb_parent_changed),
+				  NULL);
+		cb_parent_changed (item);
+	}
+
+	return context;
+}
+#endif
