@@ -321,13 +321,15 @@ goc_offscreen_box_size_allocate (GtkWidget     *widget,
 
 	gtk_widget_set_allocation (widget, allocation);
 
-	if (gtk_widget_get_realized (widget))
+	if (gtk_widget_get_realized (widget)) {
+		/* See https://bugzilla.gnome.org/show_bug.cgi?id=698758 */
+		guint h = MIN (allocation->height, 0x7fff);
+		guint w = MIN (allocation->width, 0x7fff);
 		gdk_window_move_resize (gtk_widget_get_window (widget),
 		                        allocation->x,
 		                        allocation->y,
-		                        allocation->width,
-		                        allocation->height);
-
+		                        w, h);
+	}
 
 	if (offscreen_box->child
 	    && gtk_widget_get_visible (offscreen_box->child)) {
@@ -335,18 +337,18 @@ goc_offscreen_box_size_allocate (GtkWidget     *widget,
 		GtkAllocation child_allocation;
 
 		gtk_widget_get_preferred_size (offscreen_box->child,
-				             &child_requisition, NULL);
+					       &child_requisition, NULL);
 		child_allocation.x = 0;
 		child_allocation.y = 0;
 		child_allocation.width = child_requisition.width;
 		child_allocation.height = child_requisition.height;
 
 		if (gtk_widget_get_realized (widget))
-		gdk_window_move_resize (offscreen_box->offscreen_window,
-					child_allocation.x,
-				        child_allocation.y,
-					child_allocation.width,
-				        child_allocation.height);
+			gdk_window_move_resize (offscreen_box->offscreen_window,
+						child_allocation.x,
+						child_allocation.y,
+						child_allocation.width,
+						child_allocation.height);
 
 		gtk_widget_size_allocate (offscreen_box->child, &child_allocation);
 	}
@@ -575,6 +577,33 @@ cb_canvas_changed (GocWidget *item, G_GNUC_UNUSED GParamSpec *pspec,
 	g_object_unref (w);
 }
 
+static void
+goc_widget_connect_signals (GtkWidget *widget, GocWidget *item,
+			    gboolean do_connect)
+{
+		if (GTK_IS_CONTAINER (widget)) {
+			GList *children = gtk_container_get_children (GTK_CONTAINER (widget));
+			GList *ptr;
+			for (ptr = children; ptr; ptr = ptr->next) {
+				GtkWidget *child = ptr->data;
+				goc_widget_connect_signals (child, item, do_connect);
+			}
+			g_list_free (children);
+		}
+
+		if (do_connect) {
+			g_signal_connect (widget, "enter-notify-event",
+					  G_CALLBACK (enter_notify_cb), item);
+			g_signal_connect (widget, "button-press-event",
+					  G_CALLBACK (button_press_cb), item);
+		} else {
+			g_signal_handlers_disconnect_by_func
+				(widget, G_CALLBACK (enter_notify_cb), item);
+			g_signal_handlers_disconnect_by_func
+				(widget, G_CALLBACK (button_press_cb), item);
+		}
+}
+
 static void
 goc_widget_set_widget (GocWidget *item, GtkWidget *widget)
 {
@@ -584,10 +613,7 @@ goc_widget_set_widget (GocWidget *item, GtkWidget *widget)
 	if (item->ofbox) {
 		GtkWidget *parent = gtk_widget_get_parent (item->ofbox);
 
-		g_signal_handlers_disconnect_by_func
-			(item->ofbox, G_CALLBACK (enter_notify_cb), item);
-		g_signal_handlers_disconnect_by_func
-			(item->ofbox, G_CALLBACK (button_press_cb), item);
+		goc_widget_connect_signals (item->widget, item, FALSE);
 
 		if (parent)
 			gtk_container_remove (GTK_CONTAINER (parent),
@@ -612,10 +638,7 @@ goc_widget_set_widget (GocWidget *item, GtkWidget *widget)
 					item->ofbox, item->x, item->y);
 		goc_widget_notify_scrolled (GOC_ITEM (item));
 		/* we need to propagate some signals to the parent item */
-		g_signal_connect (widget, "enter-notify-event",
-				  G_CALLBACK (enter_notify_cb), item);
-		g_signal_connect (widget, "button-press-event",
-				  G_CALLBACK (button_press_cb), item);
+		goc_widget_connect_signals (widget, item, TRUE);
 	}
 }
 
@@ -703,7 +726,7 @@ goc_widget_distance (GocItem *item, double x, double y, GocItem **near_item)
 	}
 	if (y < widget->y) {
 		dy = widget->y - y;
-	} else if (x < widget->y + widget->h) {
+	} else if (y < widget->y + widget->h) {
 		dy = 0;
 	} else {
 		dy = y - widget->y - widget->h;
