@@ -122,6 +122,19 @@ go_sys_extern_plugin_dir (void)
 	return libgoffice_extern_plugin_dir;
 }
 
+#ifdef GOFFICE_WITH_GTK
+static void
+install_icons (void)
+{
+	GdkPixbuf *pixbuf = go_gdk_pixbuf_load_from_file ("res:go:utils/unknown_image.png");
+	int size = gdk_pixbuf_get_width (pixbuf);
+	gtk_icon_theme_add_builtin_icon ("unknown_image",
+					 size,
+					 pixbuf);
+	g_object_unref (pixbuf);
+}
+#endif
+
 
 /**
  * libgoffice_init:
@@ -184,7 +197,9 @@ libgoffice_init (void)
 
 	bindtextdomain (GETTEXT_PACKAGE, libgoffice_locale_dir);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#if (!GLIB_CHECK_VERSION (2, 36, 0))
 	g_type_init ();
+#endif
 	gsf_init ();
 
 	_go_string_init ();
@@ -199,6 +214,7 @@ libgoffice_init (void)
 	_gog_plugin_services_init ();
 #ifdef GOFFICE_WITH_GTK
 	_goc_plugin_services_init ();
+	install_icons ();
 #endif
 	(void) GOG_TYPE_GRAPH;
 	(void) GOG_TYPE_CHART;
@@ -208,6 +224,7 @@ libgoffice_init (void)
 	(void) GOG_TYPE_LEGEND;
 	(void) GOG_TYPE_AXIS;
 	(void) GOG_TYPE_AXIS_LINE;
+	(void) GOG_TYPE_COLOR_SCALE;
 	(void) GOG_TYPE_LABEL;
 	(void) GOG_TYPE_GRID;
 	(void) GOG_TYPE_GRID_LINE;
