@@ -570,6 +570,17 @@ gog_color_scale_view_render (GogView *view, GogViewAllocation const *bbox)
 		tick_size = gog_renderer_pt2r (view->renderer, scale->tick_size);
 	} else
 		line_width = tick_size = 0.;
+	if (min == max || first == last) {
+		/* avoid infinites and nans later, this might happen if no data are available */
+		if (min < first)
+			first = min;
+		else
+			min = first;
+		if (max > last)
+			last = max;
+		else
+			max = last;
+	}
 	if (scale->horizontal) {
 		scale_area.x = view->residual.x;
 		/* we make sure that we have enough room to display the last and first labels */
@@ -723,7 +734,7 @@ gog_color_scale_view_render (GogView *view, GogViewAllocation const *bbox)
 				if (j == 0 || !go_geometry_test_OBR_overlap (obrs + j, obrs + l)) {
 					gog_renderer_draw_gostring (view->renderer, ticks[i].str,
 						                        &label_pos, anchor,
-							                    GTK_JUSTIFY_CENTER, -1.);
+							                    GO_JUSTIFY_CENTER, -1.);
 					l = j;
 				}
 				j++;
@@ -761,7 +772,7 @@ gog_color_scale_view_render (GogView *view, GogViewAllocation const *bbox)
 				if (j == 0 || !go_geometry_test_OBR_overlap (obrs + j, obrs + l)) {
 					gog_renderer_draw_gostring (view->renderer, ticks[i].str,
 						                        &label_pos, anchor,
-							                    GTK_JUSTIFY_CENTER, -1.);
+							                    GO_JUSTIFY_CENTER, -1.);
 					l = j;
 				}
 				j++;
