@@ -25,6 +25,20 @@
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
 
+/**
+ * GogRegCurveDrawingBounds:
+ * @GOG_REG_CURVE_DRAWING_BOUNDS_NONE: no limits.
+ * @GOG_REG_CURVE_DRAWING_BOUNDS_ABSOLUTE: absolute limits.
+ * @GOG_REG_CURVE_DRAWING_BOUNDS_RELATIVE: limits relative to the data range.
+ **/
+
+/**
+ * GogRegCurveClass:
+ * @get_value_at: returns the calculated value.
+ * @get_equation: gets the regresion equation as a string.
+ * @populate_editor: populates the editor.
+ **/
+
 #define GOG_REG_CURVE_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_TYPE_REG_CURVE, GogRegCurveClass))
 
 static GObjectClass *reg_curve_parent_klass;
@@ -110,7 +124,7 @@ gog_reg_curve_populate_editor (GogObject	*gobj,
 	struct reg_curve_closure *cl;
 	GogRegCurveDrawingBounds db = GOG_REG_CURVE (gobj)->drawing_bounds;
 
-	gui = go_gtk_builder_new_internal ("res:go:graph/gog-reg-curve-prefs.ui", GETTEXT_PACKAGE, cc);
+	gui = go_gtk_builder_load_internal ("res:go:graph/gog-reg-curve-prefs.ui", GETTEXT_PACKAGE, cc);
 	if (gui == NULL)
 		return;
 
