@@ -649,7 +649,7 @@ find_builtin (const char *fmtstr, int page, gboolean def)
 	if (page == GO_FORMAT_UNKNOWN)
 		return NULL;
 
-	candidates = _go_format_builtins[page];
+	candidates = _go_format_builtins (page);
 	if (!candidates)
 		return NULL;
 
@@ -900,7 +900,7 @@ stays:
 			select.stamp = 0;
 			gtk_list_store_clear (gfs->format.formats.model);
 			for (; start <= end ; ++start)
-				fmt_dialog_init_fmt_list (gfs, _go_format_builtins[start],
+				fmt_dialog_init_fmt_list (gfs, _go_format_builtins (start),
 							  &select, fhash);
 
 			if  (page == FMT_CUSTOM) {
@@ -1252,8 +1252,8 @@ cb_format_currency_select (GtkComboBoxText *combo, GOFormatSel *gfs)
 		return FALSE;
 	}
 
-	for (i = 0; _go_format_currencies[i].symbol != NULL ; ++i) {
-		GOFormatCurrency const *ci = _go_format_currencies + i;
+	for (i = 0; _go_format_currencies ()[i].symbol != NULL ; ++i) {
+		GOFormatCurrency const *ci = _go_format_currencies () + i;
 		if (!strcmp (_(ci->description), new_text)) {
 			gfs->format.details.currency = ci;
 			break;
@@ -1655,8 +1655,8 @@ nfs_init (GOFormatSel *gfs)
 		GtkEntry *entry =
 			GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo)));
 
-		for (i = 0; _go_format_currencies[i].symbol != NULL ; ++i)
-			l = g_slist_prepend (l, _((gchar *)_go_format_currencies[i].description));
+		for (i = 0; _go_format_currencies ()[i].symbol != NULL ; ++i)
+			l = g_slist_prepend (l, _((gchar *)_go_format_currencies ()[i].description));
 		l = g_slist_sort (l, funny_currency_order);
 
 		for (ptr = l; ptr != NULL ; ptr = ptr->next)
