@@ -39,6 +39,7 @@
 #include <goffice/gtk/go-combo-color.h>
 #include <goffice/gtk/go-combo-pixmaps.h>
 #include <goffice/gtk/go-font-sel.h>
+#include <goffice/gtk/go-font-sel-dialog.h>
 #include <goffice/gtk/go-format-sel.h>
 #include <goffice/gtk/go-gradient-selector.h>
 #include <goffice/gtk/go-graph-widget.h>
@@ -55,10 +56,18 @@ G_BEGIN_DECLS
 
 void	   go_gtk_editable_enters (GtkWindow *window, GtkWidget *w);
 
+GtkBuilder *go_gtk_builder_load_internal (char const *uifile,
+					 char const *domain, GOCmdContext *gcc);
+GtkBuilder *go_gtk_builder_load (char const *uifile,
+				char const *domain, GOCmdContext *gcc);
+#ifndef GOFFICE_DISABLE_DEPRECATED
+GOFFICE_DEPRECATED_FOR(go_gtk_builder_load_internal)
 GtkBuilder *go_gtk_builder_new_internal (char const *uifile,
 					 char const *domain, GOCmdContext *gcc);
+GOFFICE_DEPRECATED_FOR(go_gtk_builder_load)
 GtkBuilder *go_gtk_builder_new (char const *uifile,
 				char const *domain, GOCmdContext *gcc);
+#endif
 gulong	   go_gtk_builder_signal_connect (GtkBuilder *gui,
 					  gchar const *instance_name,
 					  gchar const *detailed_signal,
@@ -79,10 +88,6 @@ void	   go_gtk_combo_box_remove_text (GtkComboBox *combo, int position);
 int	   go_gtk_builder_group_value (GtkBuilder *gui,
 				       char const * const group[]);
 
-int	   go_pango_measure_string	(PangoContext *context,
-					 PangoFontDescription const *font_desc,
-					 char const *str);
-
 gint       go_gtk_dialog_run		(GtkDialog *dialog, GtkWindow *parent);
 GtkWidget *go_gtk_dialog_add_button	(GtkDialog *dialog, char const *text,
 					 char const *stock_id,
@@ -95,8 +100,16 @@ void       go_gtk_notice_nonmodal_dialog (GtkWindow *parent, GtkWidget **ref,
 gboolean   go_gtk_query_yes_no		(GtkWindow *toplevel, gboolean default_answer,
 					 const gchar *format, ...) G_GNUC_PRINTF (3, 4);
 
+GtkWidget *go_gtk_button_build_with_stock (char const *text,
+					 char const *stock_id);
+#ifndef GOFFICE_DISABLE_DEPRECATED
+GOFFICE_DEPRECATED_FOR(go_gtk_button_build_with_stock)
 GtkWidget *go_gtk_button_new_with_stock (char const *text,
 					 char const *stock_id);
+#endif
+void	   go_gtk_widget_replace	(GtkWidget *victim,
+					 GtkWidget *replacement);
+void       go_gtk_grid_remove_row       (GtkGrid *grid, int row);
 void	   go_gtk_widget_disable_focus	(GtkWidget *w);
 void       go_gtk_window_set_transient  (GtkWindow *toplevel, GtkWindow *window);
 void	   go_gtk_help_button_init	(GtkWidget *w, char const *data_dir,
