@@ -21,6 +21,14 @@
 #include "go-font.h"
 #include "go-glib-extras.h"
 #include <pango/pango-layout.h>
+#include <string.h>
+
+/**
+ * GOFontScript:
+ * @GO_FONT_SCRIPT_SUB: subscript.
+ * @GO_FONT_SCRIPT_STANDARD: normal.
+ * @GO_FONT_SCRIPT_SUPER: superscript.
+ **/
 
 static GHashTable	*font_hash;
 static GPtrArray	*font_array;
@@ -33,6 +41,20 @@ static GOFont const	*font_default;
 #define ref_debug(x)	do { } while (0)
 #endif
 
+GType
+go_font_get_type (void)
+{
+	static GType type = 0;
+
+	if (type == 0)
+		type = g_boxed_type_register_static
+			("GOFont",
+			 (GBoxedCopyFunc) go_font_ref,
+			 (GBoxedFreeFunc) go_font_unref);
+
+    return type;
+}
+
 static void
 go_font_free (GOFont *font)
 {
@@ -162,10 +184,13 @@ go_font_cache_unregister (GClosure *watcher)
 	font_watchers = g_slist_remove (font_watchers, watcher);
 }
 
-/*
- * Returns a sorted list of strings of font family names.  The list and
- * the names must be freed.
- */
+/**
+ * go_fonts_list_families:
+ * @context: #PangoContext
+ *
+ * Returns: (element-type char) (transfer full):  a sorted list of strings of
+ * font family names.  The list and the names must be freed.
+ **/
 GSList *
 go_fonts_list_families (PangoContext *context)
 {
@@ -185,6 +210,12 @@ go_fonts_list_families (PangoContext *context)
 	return res;
 }
 
+/**
+ * go_fonts_list_sizes:
+ *
+ * Returns: (element-type void) (transfer container):  a sorted list of font
+ * sizes in Pango units.  The list must be freed.
+ **/
 GSList *
 go_fonts_list_sizes (void)
 {
@@ -298,6 +329,27 @@ go_font_metrics_free (GOFontMetrics *metrics)
 	g_free (metrics);
 }
 
+static GOFontMetrics *
+go_font_metrics_copy (GOFontMetrics *file_permissions)
+{
+	GOFontMetrics *res = g_new (GOFontMetrics, 1);
+	memcpy (res, file_permissions, sizeof(GOFontMetrics));
+	return res;
+}
+
+GType
+go_font_metrics_get_type (void)
+{
+	static GType t = 0;
+
+	if (t == 0) {
+		t = g_boxed_type_register_static ("GOFontMetrics",
+			 (GBoxedCopyFunc)go_font_metrics_copy,
+			 (GBoxedFreeFunc)go_font_metrics_free);
+	}
+	return t;
+}
+
 static GOFontMetrics go_font_metrics_unit_var;
 
 /* All widths == 1.  */
