@@ -14,7 +14,7 @@ void	 go_ptr_array_insert	(GPtrArray *array, gpointer value, int index);
 GSList	*go_hash_keys		(GHashTable *hash);
 
 GSList	*go_slist_map		(GSList const *list, GOMapFunc map_func);
-GSList	*go_slist_create	(gpointer item1, ...);
+GSList	*go_slist_create	(gconstpointer item1, ...);
 #define	 go_string_slist_copy(list) go_slist_map (list, (GOMapFunc) g_strdup)
 GSList	*go_strsplit_to_slist	(char const *str, gchar delimiter);
 #define GO_SLIST_FOREACH(list,valtype,val,stmnt) \
@@ -84,6 +84,7 @@ char const *go_guess_encoding		(char const *raw, gsize len,
 char const *go_get_real_name		(void);
 void	    go_destroy_password	(char *passwd);
 
+GType        go_mem_chunk_get_type  (void);
 GOMemChunk  *go_mem_chunk_new		(char const *name, gsize user_atom_size, gsize chunk_size);
 void	     go_mem_chunk_destroy	(GOMemChunk *chunk, gboolean expect_leaks);
 gpointer     go_mem_chunk_alloc		(GOMemChunk *chunk);
