@@ -48,6 +48,7 @@ typedef struct {
 	gboolean alpha_support;
 } GOImageFormatInfo;
 
+GType      go_image_format_info_get_type (void);
 char 	  *go_mime_to_image_format      (char const *mime_type);
 char 	  *go_image_format_to_mime      (char const *format);
 
@@ -80,7 +81,6 @@ typedef struct {
 
 	GdkPixbuf *(*get_pixbuf) (GOImage *image);
 	GdkPixbuf *(*get_scaled_pixbuf) (GOImage *image, int width, int height);
-	gboolean (*same_content) (GOImage *img1, GOImage *img2);
 	void (*save) (GOImage *image, GsfXMLOut *output);
 	void (*load_attr) (GOImage *image, xmlChar const *attr_name, xmlChar const *attr_value);
 	void (*load_data) (GOImage *image, GsfXMLIn *xin);
@@ -99,7 +99,6 @@ GOImage 	*go_image_new_for_format   	(char const *format);
 GType		 go_image_type_for_format      	(char const *format);
 
 guint8 const	*go_image_get_data 		(GOImage *image, gsize *length);
-void 		 go_image_fill 			(GOImage *image, GOColor color);
 
 void		 go_image_set_name		(GOImage *image, char const *name);
 char const	*go_image_get_name 		(GOImage const *image);
