@@ -262,7 +262,7 @@ go_line_dash_get_length (GOLineDashType type)
 {
 	GOLineDashDesc const *dash_desc;
 
-	if (type < 0 || type >= G_N_ELEMENTS (line_dashes))
+	if ((unsigned)type >= G_N_ELEMENTS (line_dashes))
 		return 1.0;
 
 	dash_desc = line_dashes[type].dash_desc;
@@ -285,7 +285,7 @@ go_line_dash_get_sequence (GOLineDashType type, double scale)
 	GOLineDashSequence *sequence = NULL;
 	GOLineDashDesc const *dash_desc;
 
-	if (type < 0 || type >= G_N_ELEMENTS (line_dashes))
+	if ((unsigned)type >= G_N_ELEMENTS (line_dashes))
 		return NULL;
 
 	dash_desc = line_dashes[type].dash_desc;
@@ -385,7 +385,7 @@ go_line_interpolation_as_label (GOLineInterpolation type)
 }
 
 /**
- * go_line_interpolation_as_str:
+ * go_line_interpolation_supports_radial:
  * @type: an interpolation type
  *
  * Returns: TRUE if the line interpolation type can be used with radial
@@ -405,7 +405,7 @@ go_line_interpolation_supports_radial (GOLineInterpolation type)
 }
 
 /**
- * go_line_interpolation_as_str:
+ * go_line_interpolation_auto_skip:
  * @type: an interpolation type
  *
  * Returns: TRUE if the line interpolation type forces skipping invalid
@@ -430,7 +430,7 @@ static struct {
 	GOArrowType typ;
 	char const *name;
 } arrow_types[] = {
-	{ GO_LINE_NONE, "none" },
+	{ GO_ARROW_NONE, "none" },
 	{ GO_ARROW_KITE, "kite" },
 	{ GO_ARROW_OVAL, "oval" }
 };
