@@ -170,10 +170,10 @@ typedef GogPlotViewClass	GogDropBarViewClass;
 /**
  * FIXME FIXME FIXME Wrong description
  * barcol_draw_rect :
- * @rend : #GogRenderer
- * @flip :
- * @base : #GogViewAllocation
- * @rect : #GogViewAllocation
+ * @rend: #GogRenderer
+ * @flip:
+ * @base: #GogViewAllocation
+ * @rect: #GogViewAllocation
  *
  * A utility routine to build a vpath in @rect.  @rect is assumed to be in
  * coordinates relative to @base with 0,0 as the upper left.  @flip transposes
@@ -298,8 +298,10 @@ gog_dropbar_view_render (GogView *view, GogViewAllocation const *bbox)
 	for (ptr = gog_1_5d_model->base.series ; ptr != NULL ; ptr = ptr->next) {
 		series = ptr->data;
 		base_series = GOG_SERIES (series);
-		if (!gog_series_is_valid (base_series))
+		if (!gog_series_is_valid (base_series)) {
+			path1[j++] = NULL;
 			continue;
+		}
 		prec_valid = FALSE;
 		neg_style = go_style_dup ((GOG_STYLED_OBJECT (series))->style);
 		neg_style->line.color ^= 0xffffff00;
