@@ -155,7 +155,7 @@ gog_box_plot_pref (GogObject *obj,
 		"toggled",
 		G_CALLBACK (display_before_grid_cb), obj);
 
-	w = go_gtk_builder_get_widget (gui, "gog_box_plot_prefs");
+	w = go_gtk_builder_get_widget (gui, "gog-box-plot-prefs");
 	g_object_set_data (G_OBJECT (w), "state", gui);
 	g_signal_connect_swapped (G_OBJECT (w), "destroy", G_CALLBACK (g_object_unref), gui);
 
